
Changelog
=========

0.1.0 (2018-03-20)
------------------

* First release on PyPI.

0.1.1 (2018-04-13)
------------------

* Flak8-compliant

0.1.2 (2018-04-14)
------------------

* added --source and --destination options to the command line
* source file can be followed (like 'tail -f ') with --follow
* destination file can contain only the last messaget (with --snapshot)
* destinations abstracted in emittargets.py

